import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="grades-check",
    version="0.0.3",
    author="Ailenei dan",
    author_email="ailenei_d1996@yahoo.com",
    description="A simple script that allows you to verify if a site changed or not",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
          'requests',
      ],
)


import sys
from webbrowser import open
import requests
from time import sleep


def stalker(url, music, sleep_seconds=2):
    first = requests.get(url).content
    while 1:
        current = requests.get(url).content
        if current != first:
            break
        sleep(sleep_seconds)

    open(music)
    print("RESULTS")


if __name__ == "__main__":
    music = "https://youtu.be/9bZkp7q19f0?t=68"
    url = sys.argv[1]
    print(sys.argv)
    if len(sys.argv) > 2:
        music = sys.argv[2]

    stalker(url, music)
